@@ -110,10 +110,14 @@ and thus creates theoretically correct notes. Will throw a \
 def interval(key, start_note, interval):
 	"""Returns the note found at the interval starting from start_note \
 in the given key. For example interval('C', 'D', 1) will return 'E'. \
-Will raise a !KeyError if the start_note is not found in the key's scale"""
-	notes = get_notes(key)
-	if start_note not in notes:
-		raise KeyError,"The start note %s of the interval "\
-				"was not found in the key %s" % (start_note, key)
-	return notes[(notes.index(start_note) + interval) % 7]
+Will raise a !KeyError if the start_note is not a valid note."""
+	
+	if not notes.is_valid_note(start_note):
+		raise KeyError,"The start note '%s' is not a valid note" % start_note
 
+	notes_in_key = get_notes(key)
+
+	for n in notes_in_key:
+		if n[0] == start_note[0]:
+			index = notes_in_key.index(n)
+	return notes_in_key[(index + interval) % 7]
